@@ -59,7 +59,8 @@ signals:
     void allContacts (bool bOk);
 
     //! Emitted when the contacts model is created
-    void setContactsModel(QAbstractItemModel *model);
+    void setContactsModel(QAbstractItemModel *model,
+                          QAbstractItemModel *searchModel);
 
 public slots:
     void refreshContacts (const QDateTime &dtUpdate);
@@ -70,12 +71,17 @@ public slots:
 
 private slots:
     //! Invoked on response to login to contacts API
-    void onLoginResponse (QNetworkReply *reply);
+    void onLoginResponse(bool success, const QByteArray &response,
+                         QNetworkReply *reply, void *ctx);
+
+#ifndef NO_CONTACTS_CAPTCHA
     //! Invoked when the captcha is done
     void onCaptchaDone (bool bOk, const QString &strCaptcha);
+#endif
 
     // Invoked when the google contacts API responds with the contacts
-    void onGotContacts (QNetworkReply *reply);
+    void onGotContactsFeed(bool success, const QByteArray &response,
+                           QNetworkReply *reply, void *ctx);
     // Invoked when one contact is parsed out of the XML
     void gotOneContact (const ContactInfo &contactInfo);
     //! Invoked when all the contacts are parsed
@@ -84,26 +90,26 @@ private slots:
     //! Invoked when the contact model tells us that the photo is not present
     void onNoContactPhoto(const ContactInfo &contactInfo);
 
-    //! Invoked when the photo tracker gets a photo
-    void onGotOnePhoto (const ContactInfo &contactInfo);
+    //! Finished getting the photo
+    void onGotPhoto(bool success, const QByteArray &response,
+                    QNetworkReply *reply, void *ctx);
 
 private:
-    QNetworkRequest createRequest(QString strUrl);
-
-    QNetworkReply *
-    postRequest (QString         strUrl,
-                 QStringPairList arrPairs,
-                 QObject        *receiver,
-                 const char     *method);
-    QNetworkReply *
-    getRequest (QString         strUrl,
-                QObject        *receiver,
-                const char     *method);
+    bool doGet(QUrl url, void *ctx, QObject *obj, const char *method);
+    bool doPost(QUrl url, QByteArray postData, const char *contentType,
+                void *ctx, QObject *receiver, const char *method);
 
     void decRef (bool rv = true);
 
+    QUrl hasMoved(QNetworkReply *reply);
+
+    bool startLogin(QUrl url);
+    bool getContactsFeed(QUrl url);
+    void updateModelWithContact(const ContactInfo &contactInfo);
+
 private:
     ContactsModel *modelContacts;
+    ContactsModel *modelSearchContacts;
 
     //! Path to the temp directory to store all contact photos
     QString         strTempStore;
@@ -113,6 +119,9 @@ private:
     //! The authentication string returned by the contacts API
     QString         strGoogleAuth;
 
+    //! Refcount for in-flight network requests
+    QAtomicInt      refCount;
+
     //! The network manager for contacts API
     QNetworkAccessManager nwMgr;
 
@@ -128,9 +137,6 @@ private:
     //! Is the contacts refresh an update process?
     bool            bRefreshIsUpdate;
 
-    //! Refcount for in-flight network requests
-    QAtomicInt      refCount;
-
     bool            bBeginDrain;
 };
 
