@@ -197,8 +197,7 @@ private slots:
     //! When two step authentication happens
     void onTwoStepAuthentication(AsyncTaskToken *token);
 
-    //! Invoked when the desktop is resized (useful only on mobile platforms)
-    void onDesktopResized();
+    void onOrientationChanged(OsIndependentOrientation o);
 
     //! When the user needs to send me logs
     void onSigSendLogs();
@@ -216,6 +215,7 @@ private:
     void initQML ();
     bool connectSettingsSignals();
 
+
     void initContacts ();
     void deinitContacts ();
 
